<?php

add_action('wp_ajax_wpslash_acs_voucher_print_receipt_list_pdf', 'wpslash_acs_voucher_print_receipt_list_pdf');

function wpslash_acs_voucher_print_receipt_list_pdf() {
	check_ajax_referer('wpslash_voucher_nonce', 'security');
	if (isset($_POST['mass_number']) && isset($_POST['date'])) {
		require_once WPSLASH_ACS_VOUCHER_PLUGIN_DIR . '/inc/functions/acs_functions.php';
		$instance_id = 'acs';
		if (isset($_POST['instance_id'])) {
			$instance_id = sanitize_text_field($_POST['instance_id']);
		}
		$mass_number = sanitize_text_field($_POST['mass_number']);
		$date = sanitize_text_field($_POST['date']);

		$acs_company_id = get_option('wc_settings_tab_wpslash_' . $instance_id . '_voucher_company_id', true);
		$acs_company_password = get_option('wc_settings_tab_wpslash_' . $instance_id . '_voucher_company_password', true);
		$acs_username = get_option('wc_settings_tab_wpslash_' . $instance_id . '_voucher_username', true);
		$acs_password = get_option('wc_settings_tab_wpslash_' . $instance_id . '_voucher_password', true);

		if (!empty($acs_company_id) && !empty($acs_company_password) && !empty($acs_username) && !empty($acs_password)) {
			$acs_response = null;

			wpslash_acs_voucher_print_receipt_list($acs_company_id, $acs_company_password, $acs_username, $acs_password, $date, $mass_number);
		} else {
			esc_html_e('Check your ACS configuration.', 'wpslash-acs-voucher');
		}

	}	
	

	wp_die();
}

add_action('wp_ajax_wpslash_acs_voucher_receipt_list_click', 'wpslash_acs_voucher_receipt_list_click');

function wpslash_acs_voucher_receipt_list_click() {
	check_ajax_referer('wpslash_voucher_nonce', 'security');
	if (isset($_POST['date'])) {
		require_once WPSLASH_ACS_VOUCHER_PLUGIN_DIR . '/inc/functions/acs_functions.php';
		$date = sanitize_text_field($_POST['date']);
		$instance_id = 'acs';
		if (isset($_POST['instance_id'])) {
			$instance_id = sanitize_text_field($_POST['instance_id']);
		}

		$acs_company_id = get_option('wc_settings_tab_wpslash_' . $instance_id . '_voucher_company_id', true);
		$acs_company_password = get_option('wc_settings_tab_wpslash_' . $instance_id . '_voucher_company_password', true);
		$acs_username = get_option('wc_settings_tab_wpslash_' . $instance_id . '_voucher_username', true);
		$acs_password = get_option('wc_settings_tab_wpslash_' . $instance_id . '_voucher_password', true);
		$acs_api_key = get_option('wc_settings_tab_wpslash_' . $instance_id . '_voucher_api_key', true);
		echo '<div class="acs_wrapper">';


		if (!empty($acs_company_id) && !empty($acs_company_password) && !empty($acs_username) && !empty($acs_password)) {
			$acs_response = null;

			//check mass numbers if exists for this day//
			if (empty($acs_api_key)) {
				$mass_numbers = wpslash_acs_voucher_get_mass_numbers($acs_company_id, $acs_company_password, $acs_username, $acs_password, $date);
			} else {
				$mass_numbers = wpslash_acs_voucher_get_mass_numbers_api($acs_api_key, $acs_company_id, $acs_company_password, $acs_username, $acs_password, $date);
			}

			//if mass numbers found print buttons to print each receipt list
			if (!empty($mass_numbers)) {
				echo '<h3>' . esc_html__('Receipts List Found', 'wpslash-acs-voucher') . '</h3>';
				echo '<div class="acs_wrapper">';
				echo '<h3>' . esc_html__('Existing Receipt Lists Found', 'wpslash-acs-voucher') . '</h3>';

				foreach ($mass_numbers as $current_mass) {

					echo '<a class="button acs_print_receipt_list" instance-id="' . esc_html($instance_id) . '" mass_number ="' . esc_html($current_mass) . '" date="' . esc_html($date) . '">' . esc_html__('Print Receipt List', 'wpslash-acs-voucher') . ' ' . esc_html($current_mass) . '</a>';
				}
				echo '</div>';

			}//end if

			//else list not exist create one

			if (empty($acs_api_key)) {
				$mass_number = wpslash_acs_voucher_create_receipt_list($acs_company_id, $acs_company_password, $acs_username, $acs_password, $date);
			} else {
				$mass_number = wpslash_acs_voucher_create_receipt_list_api($acs_api_key, $acs_company_id, $acs_company_password, $acs_username, $acs_password, $date);
			}

			if (!is_array($mass_number) && !empty($mass_number) && is_numeric($mass_number)) {
				echo '<h3>' . esc_html__('New Receipt List Created', 'wpslash-acs-voucher') . '</h3>';

				echo '<div class="acs_wrapper">';
				echo '<a class="button acs_print_receipt_list" instance-id="' . esc_html($instance_id) . '" mass_number ="' . esc_html($mass_number) . '" date="' . esc_html($date) . '">' . esc_html__('Print Receipt List', 'wpslash-acs-voucher') . ' ' . esc_html($mass_number) . '</a>';
				echo '<div class="acs_wrapper">';
			}//end if

			if (!is_array($mass_number) && empty($mass_number)) {
				echo '<div class="acs_message">';
				esc_html_e('No New Receipt List Created...', 'wpslash-acs-voucher') . ' ';
				echo '</div>';

			} else {
				if (empty($acs_api_key)) {
					$unprinted_vouchers = wpslash_acs_voucher_get_unprinted_vouchers($acs_company_id, $acs_company_password, $acs_username, $acs_password, $date);
				} else {
					$unprinted_vouchers = $mass_number;
				}

				if (!empty($unprinted_vouchers)) {
					echo '<h3>' . esc_html__('Unprinted Vouchers Found', 'wpslash-acs-voucher') . '</h3>';
					echo '<td><a class="button wpslash_voucher_courier_print" instance-id="' . esc_html($instance_id) . '" tracking="' . esc_html(implode('|', $unprinted_vouchers)) . '" paper="2" courier="acs">' . esc_html__('Print All Voucher A4', 'wpslash-acs-voucher') . '</a></td>';
					echo '<td><a class="button wpslash_voucher_courier_print" instance-id="' . esc_html($instance_id) . '" tracking="' . esc_html(implode('|', $unprinted_vouchers)) . '" paper="1" courier="acs">' . esc_html__('Print All Voucher Thermal', 'wpslash-acs-voucher') . '</a></td>';

					echo '<table>';

					foreach ($unprinted_vouchers as $current_voucher) {
						echo '<tr>';
						echo '<td>' . esc_html($current_voucher) . '</td>';
						echo '<td><a class="button wpslash_voucher_courier_print" instance-id="' . esc_html($instance_id) . '" tracking="' . esc_html($current_voucher) . '" paper="2" courier="acs">' . esc_html__('Print Voucher A4', 'wpslash-acs-voucher') . '</a></td>';
						echo '<td><a class="button wpslash_voucher_courier_print" instance-id="' . esc_html($instance_id) . '" tracking="' . esc_html($current_voucher) . '" paper="1" courier="acs">' . esc_html__('Print Voucher Thermal', 'wpslash-acs-voucher') . '</a></td>';

						echo '</tr>';
					}

					echo '</table>';
				}
			}
			//you have unprinted tickets//
		} else {
			esc_html_e('Check your ACS configuration.', 'wpslash-acs-voucher');
		}

		echo '</div>';
	}
	wp_die();
}


	add_action( 'wp_ajax_wpslash_voucher_acs_parcel_type_change_ajax', 'wpslash_voucher_acs_parcel_type_change_ajax' );

function wpslash_voucher_acs_parcel_type_change_ajax() {
	global $woocommerce;
	check_ajax_referer( 'wpslash_voucher_nonce', 'security' );

	if ( isset( $_POST['wpslash_voucher_order_id'] ) && isset( $_POST['wpslash_voucher_parcel_type'] ) ) {
		$order_id = (int) $_POST['wpslash_voucher_order_id'];
		$order    = wc_get_order( $order_id );

		$order->update_meta_data( 'wpslash_voucher_acs_parcel_type', sanitize_text_field( $_POST['wpslash_voucher_parcel_type'] ) );
		$order->save();
	}
	wp_die();
}


	add_action( 'wp_ajax_wpslash_voucher_acs_parcel_description_change_ajax', 'wpslash_voucher_acs_parcel_description_change_ajax' );

function wpslash_voucher_acs_parcel_description_change_ajax() {
	global $woocommerce;
	check_ajax_referer( 'wpslash_voucher_nonce', 'security' );

	if ( isset( $_POST['wpslash_voucher_order_id'] ) && isset( $_POST['wpslash_voucher_parcel_description'] ) ) {
		$order_id = (int) $_POST['wpslash_voucher_order_id'];
		$order    = wc_get_order( $order_id );

		$order->update_meta_data( 'wpslash_voucher_acs_parcel_type_description', sanitize_text_field( $_POST['wpslash_voucher_parcel_description'] ) );
		$order->save();
	}
	wp_die();
}


